@@ -11,7 +11,7 @@ import zipfile
 from pathlib import Path
 from typing import List, Optional, Text
 
-from natsort import natsorted
+from natsort import natsorted, ns
 from PIL import Image
 
 from .comicinfoxml import ComicInfoXml
@@ -128,7 +128,7 @@ class ComicArchive:
     class ArchiveType:
         """Types of archives supported. Currently only .cbz"""
 
-        Zip, Unknown = list(range(2))
+        zip, unknown = list(range(2))
 
     def __init__(self, path: Path) -> None:
         self.path = path
@@ -139,7 +139,7 @@ class ComicArchive:
         self.page_list: Optional[List[str]] = None
         self.metadata: Optional[GenericMetadata] = None
 
-        self.archive_type: int = self.ArchiveType.Zip
+        self.archive_type: int = self.ArchiveType.zip
         self.archiver = ZipArchiver(self.path)
 
     def reset_cache(self) -> None:
@@ -157,12 +157,12 @@ class ComicArchive:
     def is_zip(self) -> bool:
         """Returns a boolean as to whether an archive is a zipfile"""
 
-        return self.archive_type == self.ArchiveType.Zip
+        return self.archive_type == self.ArchiveType.zip
 
     def is_writable(self) -> bool:
         """Returns a boolean as to whether an archive is writable"""
 
-        if self.archive_type == self.ArchiveType.Unknown:
+        if self.archive_type == self.ArchiveType.unknown:
             return False
 
         return bool(os.access(self.path, os.W_OK))
@@ -211,15 +211,7 @@ class ComicArchive:
             # seems like some archive creators are on  Windows, and don't know
             # about case-sensitivity!
             if sort_list:
-
-                def keyfunc(k):
-                    # hack to account for some weird scanner ID pages
-                    # basename=os.path.split(k)[1]
-                    # if basename < '0':
-                    #    k = os.path.join(os.path.split(k)[0], "z" + basename)
-                    return k.lower()
-
-                files = natsorted(files, key=keyfunc)
+                files = natsorted(files, alg=ns.IGNORECASE)
 
             # make a sub-list of image files
             self.page_list = []
