@@ -102,8 +102,8 @@ class ComicInfoXml:
 
         # build a tree structure
         root = ET.Element("ComicInfo")
-        root.attrib["xmlns:xsi"] = "http://www.w3.org/2001/XMLSchema-instance"
-        root.attrib["xmlns:xsd"] = "http://www.w3.org/2001/XMLSchema"
+        root.attrib["xmlns:xsi"] = "https://www.w3.org/2001/XMLSchema-instance"
+        root.attrib["xmlns:xsd"] = "https://www.w3.org/2001/XMLSchema"
         # helper func
 
         def assign(cix_entry: str, md_entry: Optional[str]) -> None:
@@ -280,15 +280,13 @@ class ComicInfoXml:
                 or credit_node.tag == "Colorist"
                 or credit_node.tag == "Letterer"
                 or credit_node.tag == "Editor"
-            ):
-                if credit_node.text is not None:
-                    for name in credit_node.text.split(","):
-                        metadata.add_credit(name.strip(), credit_node.tag)
+            ) and credit_node.text is not None:
+                for name in credit_node.text.split(","):
+                    metadata.add_credit(name.strip(), credit_node.tag)
 
-            if credit_node.tag == "CoverArtist":
-                if credit_node.text is not None:
-                    for name in credit_node.text.split(","):
-                        metadata.add_credit(name.strip(), "Cover")
+            if credit_node.tag == "CoverArtist" and credit_node.text is not None:
+                for name in credit_node.text.split(","):
+                    metadata.add_credit(name.strip(), "Cover")
 
         # parse page data now
         pages_node = root.find("Pages")
